@@ -357,7 +357,7 @@ sub gen_enum_stuff {
 	my ($typemacro, $classname, $package) = @_;
 	push @header, "#ifdef $typemacro
   /* GEnum $classname */
-# define Sv$classname(sv)	(gperl_convert_enum ($typemacro, sv))
+# define Sv$classname(sv)	(($classname)gperl_convert_enum ($typemacro, sv))
 # define newSV$classname(val)	(gperl_convert_back_enum ($typemacro, val))
 #endif /* $typemacro */
 ";
@@ -372,7 +372,7 @@ sub gen_flags_stuff {
 	my ($typemacro, $classname, $package) = @_;
 	push @header, "#ifdef $typemacro
   /* GFlags $classname */
-# define Sv$classname(sv)	(gperl_convert_flags ($typemacro, sv))
+# define Sv$classname(sv)	(($classname)gperl_convert_flags ($typemacro, sv))
 # define newSV$classname(val)	(gperl_convert_back_flags ($typemacro, val))
 #endif /* $typemacro */
 ";
@@ -432,7 +432,9 @@ sub gen_object_stuff {
 ";
 
 	push @typemap, "$classname *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "const $classname *	T_GPERL_GENERIC_WRAPPER";
 	push @typemap, "$classname\_ornull *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "const $classname\_ornull *	T_GPERL_GENERIC_WRAPPER";
 	push @boot, "#ifdef $typemacro
 gperl_register_object ($typemacro, \"$package\");
 #endif /* $typemacro */";
@@ -482,7 +484,7 @@ muppet <scott at asofyet dot org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2004 by the gtk2-perl team (see the file AUTHORS for the
+Copyright (C) 2003-2005 by the gtk2-perl team (see the file AUTHORS for the
 full list)
 
 This library is free software; you can redistribute it and/or modify it under
