@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.77.2.2 2005/06/22 22:58:41 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.82 2005/07/12 00:31:28 kaffeetisch Exp $
 #
 
 package Gtk2;
@@ -31,7 +31,7 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '1.082';
+our $VERSION = '1.092';
 
 our @ISA = qw(DynaLoader);
 
@@ -92,6 +92,12 @@ use overload
 	'==' => \&Gtk2::Gdk::Atom::eq,
 	fallback => 1;
 
+package Gtk2::TreeSortable::IterCompareFunc;
+
+use overload
+	'&{}' => sub { \&Gtk2::TreeSortable::IterCompareFunc::invoke },
+	fallback => 1;
+
 package Gtk2;
 
 
